Aydin Denoising of the Noisy ‘New York’ Test Image
==============================================================


.. raw:: html

   <iframe src="https://docs.google.com/document/d/e/2PACX-1vTN02pamOpFk5MrVg7lLRxwU_I0jj7IvEjUVYIoGEamnDaOXD4RGoiduN0eLrZLCiiwpYQFNvsCJecO/pub?embedded=true" height="9680" width="720"></iframe>
